@@ -6,8 +6,8 @@ sub specs {
 
     return {
 
-        code          => "5998",
-        description   => "Audio Tape Labels",
+        code          => '5998',
+        description   => 'Audio Tape Labels',
 
         sheet_width   => 8.5,
         sheet_height  => 11,
@@ -23,7 +23,7 @@ sub specs {
         margin_right  => 0.5,
         margin_bottom => 0.5,
 
-        units         => "in",
+        units         => 'in',
 
     };
 
