@@ -6,8 +6,8 @@ sub specs {
 
     return {
 
-        code          => "74551",
-        description   => "Insertable Name Badges - 2 1/2" x 3 3/4"",
+        code          => '74551',
+        description   => 'Insertable Name Badges - 2 1/2" x 3 3/4"',
 
         sheet_width   => 8.5,
         sheet_height  => 11.001,
@@ -23,7 +23,7 @@ sub specs {
         margin_right  => 0.5,
         margin_bottom => 0.5625,
 
-        units         => "in",
+        units         => 'in',
 
     };
 
