@@ -6,8 +6,8 @@ sub specs {
 
     return {
 
-        code          => "8389",
-        description   => "Glossy Photo Quality Postcards",
+        code          => '8389',
+        description   => 'Glossy Photo Quality Postcards',
 
         sheet_width   => 8.5,
         sheet_height  => 11,
@@ -23,7 +23,7 @@ sub specs {
         margin_right  => 1.25,
         margin_bottom => 1.25,
 
-        units         => "in",
+        units         => 'in',
 
     };
 
